==> 0.1.3.tar.gz: lib/overlay.dart <==
import 'dart:convert';
import 'package:flutter/material.dart';
import 'onairosapi.dart';

class OnairosOverlay extends StatefulWidget {
  final Map<String, dynamic> data;
  String username;
  String modelKey;
  final Function onResolved;

  OnairosOverlay({
    super.key, 
    required this.data, 
    required this.username,
    required this.modelKey,
    required this.onResolved
  });

  @override
  _OnairosOverlayState createState() => _OnairosOverlayState();
}

class _OnairosOverlayState extends State<OnairosOverlay> {
  Map<String, bool> selections = {};
  late String details;
  final onairosapi _apiService = onairosapi(
      baseUrl: 'https://api2.onairos.uk', // Replace with your actual base URL
    // baseUrl: 'http://localhost:8080', // Replace with your actual base URL
    // apiKey: 'your_api_key_here', // Replace with your actual API key
  );
  
  @override
  void initState() {
    super.initState();
    getDetails();
    // Initialize selection state
    widget.data.forEach((key, value) {
      selections[key] = false;
    });
  }

  Future<void> getDetails() async {
    // Get username

    // Get Account Info
    final onairosapi _apiService = onairosapi(
    baseUrl: 'https://api2.onairos.uk', // Replace with your actual base URL
    // apiKey: 'your_api_key_here', // Replace with your actual API key
    );

    try {
      final response = await _apiService.post('getAccountInfo', jsonData: jsonEncode({
        'Info': {
          'username': widget.username,
        },
      }));

      details = response['data'];
    } catch (e) {
      // Handle error
    }
  }
  void closeOverlay(BuildContext context) {
    Navigator.pop(context);
  }

  Future<void> confirmSelection(BuildContext context, Map<String, dynamic> selections) async {
    try {
      final response = await _apiService.post('developer/authCode', jsonData: jsonEncode({
        'details': {
          'username':widget.username,
          'developerURL': "devURL",
          'PIN':"key",
        },
      }));
  
    //Get Auth Code from Onairos server
    String; final authCode = response['authCode'];
    //Send Selections and Auth Code back to Server
    var api_url = await sendSelectionsBackToUserApp(selections, authCode);
    // Callback set in App, so that once api url is retrieved they can call their own function with api url as input to fetch data
    // callback(api_url);
    widget.onResolved(api_url);
    closeOverlay(context);
    } catch (e) {
      // Handle error
    }

  }

  Future<String?> sendSelectionsBackToUserApp(Map<String, dynamic> selections, String authCode) async {
    var apiURL = "";
    try {
      final response = await _apiService.post('developer/authCode', jsonData: jsonEncode({
        'details': {
          'username':widget.username,
          'selections':selections,
        },
      }));
      if(response != null){
        apiURL = response['url'];
        return apiURL;
      }
    }catch(e){
      throw 'Error getting API from backend';
    }
    return null;
  }

  int get selectedCount => selections.values.where((selected) => selected).length;
@override
Widget build(BuildContext context) {
  return Container(
    // Consider removing the fixed height or make it more flexible
    decoration: const BoxDecoration(
      color: Colors.white,
      borderRadius: BorderRadius.only(
        topLeft: Radius.circular(10),
        topRight: Radius.circular(10),
      ),
    ),
    child: Column(
        children: [
          // Top banner with logo and title
          Container(
            padding: const EdgeInsets.symmetric(horizontal: 10, vertical: 5),
            color: Colors.blue, // Use your brand color
            child: Row(
              mainAxisAlignment: MainAxisAlignment.spaceBetween,
              children: [
                // Place your logo here
                // Image.asset('assets/images/OnairosBlack.png', height: 50), // Replace with your asset path
                const Text('Onairos', style: TextStyle(fontSize: 24, color: Colors.white)),
                IconButton(
                  icon: const Icon(Icons.close, color: Colors.white),
                  onPressed: () => closeOverlay(context),
                ),
              ],
            ),
          ),
          // Use Expanded for the ListView to take up remaining space
        Expanded(
          child: ListView.builder(
            itemCount: widget.data.length,
            itemBuilder: (context, index) {
              String key = widget.data.keys.elementAt(index);
              var value = widget.data[key];
              return Card(
                child: CheckboxListTile(
                  title: Text('${value['type']} Insight'),
                  subtitle: Text('Description: ${value['descriptions']}'),
                  secondary: value['reward'].isNotEmpty ? Text('Reward: ${value['reward']}') : null,
                  value: selections[key],
                  onChanged: (bool? newValue) {
                    setState(() {
                      selections[key] = newValue!;
                    });
                  },
                ),
              );
            },
          ),
        ),
          // Bottom buttons with item count
          Padding(
            padding: const EdgeInsets.all(8),
            child: Row(
              mainAxisAlignment: MainAxisAlignment.spaceBetween,
              children: [
                ElevatedButton(
                  onPressed: () => closeOverlay(context),
                  child: const Text('Cancel'),
                ),
                Text('Selected: $selectedCount'),
                ElevatedButton(
                  onPressed: () => confirmSelection(context, selections), // Implement your submit logic
                  child: const Text('Confirm'),
                ),
              ],
            ),
          ),
        ],
      ),
    );
  }
}

==> 0.1.5.tar.gz: lib/overlay.dart <==
import 'dart:convert';
import 'package:flutter/material.dart';
import 'onairosapi.dart';

class OnairosOverlay extends StatefulWidget {
  final Map<String, dynamic> data;
  String username;
  String modelKey;
  final Function onResolved;

  OnairosOverlay({
    super.key, 
    required this.data, 
    required this.username,
    required this.modelKey,
    required this.onResolved
  });

  @override
  _OnairosOverlayState createState() => _OnairosOverlayState();
}

class _OnairosOverlayState extends State<OnairosOverlay> {
  Map<String, bool> selections = {};
  late String details;
  final onairosapi _apiService = onairosapi(
      baseUrl: 'https://api2.onairos.uk', // Replace with your actual base URL
    // baseUrl: 'http://localhost:8080', // Replace with your actual base URL
    // apiKey: 'your_api_key_here', // Replace with your actual API key
  );
  
  @override
  void initState() {
    super.initState();
    getDetails();
    // Initialize selection state
    widget.data.forEach((key, value) {
      selections[key] = false;
    });
  }

  Future<void> getDetails() async {
    // Get username

    // Get Account Info
    final onairosapi _apiService = onairosapi(
    baseUrl: 'https://api2.onairos.uk', // Replace with your actual base URL
    // apiKey: 'your_api_key_here', // Replace with your actual API key
    );

    try {
      final response = await _apiService.post('getAccountInfo', jsonData: jsonEncode({
        'Info': {
          'username': widget.username,
        },
      }));

      details = response['data'];
    } catch (e) {
      // Handle error
    }
  }
  void closeOverlay(BuildContext context) {
    Navigator.pop(context);
  }

  Future<void> confirmSelection(BuildContext context, Map<String, dynamic> selections) async {
    try {
      final response = await _apiService.post('getAPIUrl', jsonData: jsonEncode({
        'details': {
          'username':widget.username,
          'developerURL': "devURL",
          'PIN':"key",
        },
      }));
  
    //Get Auth Code from Onairos server
    String; final authCode = response['authCode'];
    String; final accessToken = response['accessToken'];
    //Send Selections and Auth Code back to Server
    var api_url = await sendSelectionsBackToUserApp(selections, authCode);
    // Callback set in App, so that once api url is retrieved they can call their own function with api url as input to fetch data
    // callback(api_url);
    widget.onResolved(api_url, accessToken);
    closeOverlay(context);
    } catch (e) {
      // Handle error
    }

  }

  Future<String?> sendSelectionsBackToUserApp(Map<String, dynamic> selections, String authCode) async {
    var apiURL = "";
    try {
      final response = await _apiService.post('developer/authCode', jsonData: jsonEncode({
        'details': {
          'username':widget.username,
          'selections':selections,
        },
      }));
      if(response != null){
        apiURL = response['url'];
        return apiURL;
      }
    }catch(e){
      throw 'Error getting API from backend';
    }
    return null;
  }

  int get selectedCount => selections.values.where((selected) => selected).length;
@override
Widget build(BuildContext context) {
  return Container(
    // Consider removing the fixed height or make it more flexible
    decoration: const BoxDecoration(
      color: Colors.white,
      borderRadius: BorderRadius.only(
        topLeft: Radius.circular(10),
        topRight: Radius.circular(10),
      ),
    ),
    child: Column(
        children: [
          // Top banner with logo and title
          Container(
            padding: const EdgeInsets.symmetric(horizontal: 10, vertical: 5),
            color: Colors.blue, // Use your brand color
            child: Row(
              mainAxisAlignment: MainAxisAlignment.spaceBetween,
              children: [
                // Place your logo here
                // Image.asset('assets/images/OnairosBlack.png', height: 50), // Replace with your asset path
                const Text('Onairos', style: TextStyle(fontSize: 24, color: Colors.white)),
                IconButton(
                  icon: const Icon(Icons.close, color: Colors.white),
                  onPressed: () => closeOverlay(context),
                ),
              ],
            ),
          ),
          // Use Expanded for the ListView to take up remaining space
        Expanded(
          child: ListView.builder(
            itemCount: widget.data.length,
            itemBuilder: (context, index) {
              String key = widget.data.keys.elementAt(index);
              var value = widget.data[key];
              return Card(
                child: CheckboxListTile(
                  title: Text('${value['type']} Insight'),
                  subtitle: Text('Description: ${value['descriptions']}'),
                  secondary: value['reward'].isNotEmpty ? Text('Reward: ${value['reward']}') : null,
                  value: selections[key],
                  onChanged: (bool? newValue) {
                    setState(() {
                      selections[key] = newValue!;
                    });
                  },
                ),
              );
            },
          ),
        ),
          // Bottom buttons with item count
          Padding(
            padding: const EdgeInsets.all(8),
            child: Row(
              mainAxisAlignment: MainAxisAlignment.spaceBetween,
              children: [
                ElevatedButton(
                  onPressed: () => closeOverlay(context),
                  child: const Text('Cancel'),
                ),
                Text('Selected: $selectedCount'),
                ElevatedButton(
                  onPressed: () => confirmSelection(context, selections), // Implement your submit logic
                  child: const Text('Confirm'),
                ),
              ],
            ),
          ),
        ],
      ),
    );
  }
}
